@@ -22,7 +22,10 @@ def callback(pdata, *args):
     if pdata == 1:
         print('')
         return
-    print('callback: {}'.format(pdata))
+    name, topic, _timestamp = args
+    print('start {} {} {} {} at {}'.format(pdata, name, topic, _timestamp, time.time()))
+    time.sleep(10)
+
 
 name = 'test_pub'
 
@@ -38,5 +41,5 @@ if __name__ == '__main__':
     while True:
         msg = time.time()
         pub.send(name, msg)
-        print(msg)
-        time.sleep(10)
\ No newline at end of file
+        print('send msg {}'.format(msg))
+        time.sleep(0.1)
\ No newline at end of file
